@@ -11,7 +11,6 @@ from generalpackager.api.localrepo.python.metadata_python import Metadata_Python
 class LocalRepo_Python(LocalRepo):
     _cls_target = LocalRepo.Targets.python
     _cls_metadata = Metadata_Python
-    coverage = "-"
 
     # Put in generalfile?
     @staticmethod
@@ -28,7 +27,6 @@ class LocalRepo_Python(LocalRepo):
         """ Return an absolute path to the current python exe filee. """
         return Path(sys.executable)
 
-
     def unittest(self):
         """ Run unittests for this repository.
             Sets self.coverage to total percentage with one decimal. """
@@ -45,9 +43,9 @@ class LocalRepo_Python(LocalRepo):
     @deco_require(LocalRepo.exists)
     def pip_install_editable(self):
         """ Install this repository with pip and -e flag. """
-        with self.path.as_working_dir():
+        with self.path.get_parent().as_working_dir():
             Log().debug(f"Pip install for {self}")
-            terminal("pip", "install", "-e", ".")
+            terminal("pip", "install", "-e", self.name)
 
     @deco_require(LocalRepo.exists)
     def pip_uninstall(self):
