@@ -281,6 +281,12 @@ class _PackagerFiles:
 
         return workflow.text()
 
+    @staticmethod
+    def set_collapsible(markdown):
+        for child in markdown.get_children(include_self=True):
+            if child.collapsible is None and child.header:
+                child.collapsible = False
+
     def generate_readme(self):
         """ Generate readme markdown and overwrite README.md in local repo.
 
@@ -289,7 +295,7 @@ class _PackagerFiles:
         markdown = self.get_description_markdown()
 
         # Table of contents
-        contents = Markdown(header="Contents", parent=markdown)
+        contents = Markdown(header="Table of Contents", parent=markdown, collapsible=True)
 
         # Mermaid
         self.get_mermaid_markdown().set_parent(parent=markdown)
@@ -318,6 +324,8 @@ class _PackagerFiles:
         # Generation timestamp
         self.get_footnote_markdown().set_parent(parent=markdown)
 
+        self.set_collapsible(markdown)
+
         return markdown
 
     def generate_personal_readme(self):
@@ -455,7 +463,7 @@ class _PackagerFiles:
 
         # Not in files because it writes with json not text, it's also a bit unique
         self.localrepo.metadata.name = self.name
-        # self.localrepo.metadata.write_config()
+        self.localrepo.metadata.write_config()
 
         files = [file for file in self.files if aesthetic or not file.aesthetic]
 
