@@ -1,5 +1,5 @@
 
-from generallibrary import Markdown, floor, Date, deco_cache, ObjInfo, flatten, exclusive
+from generallibrary import Markdown, floor, Date, deco_cache, ObjInfo, flatten, exclusive, comma_and_and
 from generalfile import Path
 
 import re
@@ -81,7 +81,7 @@ class _PackagerMarkdown:
         if drop_package_col:
             todos = [exclusive(todo, "Package") for todo in todos]
 
-        markdown = Markdown(header=self._todo_header)
+        markdown = Markdown(header=self._todo_header, collapsible=True)
         if todos:
             markdown.add_table_lines(*todos)
         return markdown
@@ -231,7 +231,7 @@ class _PackagerMarkdown:
         """ Get a recursive view of attributes markdown.
 
             :param generalpackager.Packager self: """
-        return Markdown(header="Attributes").add_pre_lines(self._get_attributes_view())
+        return Markdown(header="Attributes", collapsible=True).add_pre_lines(self._get_attributes_view())
 
     def get_footnote_markdown(self, commit=True):
         """ Get a markdown for footnote containing date, time and commit link.
@@ -242,7 +242,7 @@ class _PackagerMarkdown:
         if commit:
             line += f" for commit {self.github_link(text=self.commit_sha, suffix=f'commit/{self.commit_sha}')}."
 
-        return Markdown(line).wrap_with_tags("sup")
+        return Markdown(line).wrap_with_tags("<sup>", "</sup>")
 
     @staticmethod
     def _docstring_markdown(docstrings, index, parent):
@@ -269,8 +269,9 @@ class _PackagerMarkdown:
         markdown = Markdown(header="Examples")
         paths = self.localrepo.get_examples_path().get_children()
         sorted_paths = sorted(paths, key=lambda path: path.name())
-        for path in sorted_paths:  # type: Path
-            example = Markdown(header=self._header_from_path(path=path), parent=markdown)
+        for i, path in enumerate(sorted_paths):
+            collapsible = i > 0
+            example = Markdown(header=self._header_from_path(path=path), parent=markdown, collapsible=collapsible)
 
             lines = path.text.read()
             docstrings = re.findall(r'""".*?"""', lines, flags=re.S)
@@ -289,11 +290,14 @@ class _PackagerMarkdown:
     def get_contributions_markdown(self):
         """ :param generalpackager.Packager self: """
         markdown = Markdown(header="Contributions")
-        markdown.add_lines(
-            "Issue-creation and discussions are most welcome!",
-            "",
-            "Pull requests are not wanted, please discuss with me before investing any time"
-        )
+        welcome = ["Issue-creation", "discussions"]
+        contribute = self.localrepo.metadata.contribute
+
+        if contribute:
+            welcome.append("pull requests")
+        markdown.add_lines(f"{comma_and_and(*welcome, period=False)} are most welcome!",)
+        if not contribute:
+            markdown.add_lines("", "Pull requests are not wanted, please discuss with me before investing any time")
         return markdown
 
     def get_mermaid_markdown(self):
@@ -304,7 +308,7 @@ class _PackagerMarkdown:
         url_func = lambda pkg: pkg.github.url
         highlight_self = True
         markdown = self.mermaid(nodes=nodes, repr_func=repr_func, url_func=url_func, highlight_self=highlight_self)
-        markdown.header = "Dependency Diagram"
+        markdown.header = "Dependency Diagram for ManderaGeneral"
         return markdown
 
     def get_org_description_markdown(self):
